| Title: | AI Coding Agent for 'RStudio' |
|---|---|
| Description: | Provides an 'RStudio' extension with a chat interface for an AI coding agent to help users with R programming tasks. |
| Authors: | Juan Cruz Rodriguez [aut, cre] |
| Maintainer: | Juan Cruz Rodriguez <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-22 18:49:30 UTC |
| Source: | https://github.com/myownrobs/myownrobs |
Set API keys for running models locally.
configure_provider(name, api_key)configure_provider(name, api_key)
name |
Name of the provider (one of "anthropic", "deepseek", "google_gemini", "ollama", or "openai"). |
api_key |
The provider's API key to use for authentication. If 'NULL', the provider will be deleted. |
## Not run: # Configure providers. configure_provider("anthropic", Sys.getenv("ANTHROPIC_API_KEY")) configure_provider("deepseek", Sys.getenv("DEEPSEEK_API_KEY")) configure_provider("google_gemini", Sys.getenv("GEMINI_API_KEY")) configure_provider("openai", Sys.getenv("OPENAI_API_KEY")) configure_provider("ollama", Sys.getenv("OLLAMA_API_KEY")) # Delete the provider for google_gemini. configure_provider("google_gemini", NULL) ## End(Not run)## Not run: # Configure providers. configure_provider("anthropic", Sys.getenv("ANTHROPIC_API_KEY")) configure_provider("deepseek", Sys.getenv("DEEPSEEK_API_KEY")) configure_provider("google_gemini", Sys.getenv("GEMINI_API_KEY")) configure_provider("openai", Sys.getenv("OPENAI_API_KEY")) configure_provider("ollama", Sys.getenv("OLLAMA_API_KEY")) # Delete the provider for google_gemini. configure_provider("google_gemini", NULL) ## End(Not run)
Open the RStudio addin with the chat interface.
myownrobs()myownrobs()
No return value. Called for its side effects to launch the MyOwnRobs RStudio addin.
if (interactive()) { # Configure your API providers first. configure_provider("google_gemini", Sys.getenv("GEMINI_API_KEY")) # Then launch MyOwnRobs. myownrobs() }if (interactive()) { # Configure your API providers first. configure_provider("google_gemini", Sys.getenv("GEMINI_API_KEY")) # Then launch MyOwnRobs. myownrobs() }